@@ -137,7 +137,7 @@ def plot_1D(x,pressure_field,positions,show_plots,color_limits,directivity_only)
         ax.set_xlabel("X (m)")
         ax.set_ylabel("Re\{Pressure\}")
         ax.set_ylim(color_limits[0],color_limits[1])
-        
+        ax.grid("on")
 
         # Plotting the imaginary part
         ax = fig.add_subplot(223)
@@ -441,57 +441,4 @@ def define_arc(radius,numPoints,theta_lims = (0,360)):
     for i in range(0,numPoints):
         points = np.append(points,radius * np.array([[np.cos(theta[i]), np.sin(theta[i])]]),axis = 0)
         
-    return points, theta
-
-"""
-Define an array of loudspeakers
-"""
-
-def define_loudspeaker_array(num_speakers,cone_diameter,cone_separation,
-                             cone_strengths = [1],
-                             cone_phases = [0],
-                             num_points = 100,
-                             show_plots = False):
-
-    if len(cone_strengths) == 1:
-        cone_strengths = np.ones(num_speakers) * cone_strengths
-        
-    if len(cone_phases) == 1:
-        cone_phases = np.ones(num_speakers) * cone_phases
-
-    total_length = cone_diameter*num_speakers + cone_separation*num_speakers
-
-    cone_positions = np.array([])
-    for i in range(num_speakers):
-        cone_positions = np.append(cone_positions,i*cone_separation + cone_diameter/2)
-        
-    # Centering about the origin
-    cone_positions = cone_positions - max(cone_positions)/2 - cone_diameter/4
-
-
-    # Creating the array of mini-sources
-    positions = np.linspace(min(cone_positions) - cone_diameter/2,max(cone_positions)+cone_diameter/2,num_points)
-    strengths = np.zeros(len(positions))
-    phases = np.zeros(len(positions))
-    for i in range(0,len(positions)):
-
-        for j in range(0,num_speakers):
-
-            if np.abs(positions[i] - cone_positions[j]) <= cone_diameter:
-                strengths[i] = cone_strengths[j]
-                phases[i] = cone_phases[j]
-
-    if show_plots:
-        plt.figure()
-        plt.plot(positions,strengths)
-        plt.title("Speaker Cone Source Strengths")
-        plt.xlabel("Position (m)")
-        plt.ylabel("Cone Source Strength (m^3/s)")
-        
-        plt.figure()
-        plt.plot(positions,phases)
-        plt.title("Speaker Cone Source Phases")
-        plt.xlabel("Position (m)")
-        plt.ylabel("Cone Phase (rad/s)")
-        
-    return positions, strengths, phases, cone_positions
\ No newline at end of file
+    return points, theta
\ No newline at end of file
